==> haskell-hslua-repl-0.1.2-140.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-repl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-repl
version:              0.1.2
visibility:           public
id:                   hslua-repl-0.1.2-3AaabvBDyUjK5jaey3qvPg
key:                  hslua-repl-0.1.2-3AaabvBDyUjK5jaey3qvPg
license:              MIT
copyright:            © 2023-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Isocline-based Lua REPL
description:          An embeddable Lua REPL built with Isocline and HsLua.
category:             Foreign
abi:                  0e4698283a43d35a576018cbe55fdd55
exposed:              True
exposed-modules:      HsLua.REPL
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-repl-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-repl-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-repl-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-repl
hs-libraries:         HShslua-repl-0.1.2-3AaabvBDyUjK5jaey3qvPg
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
    isocline-1.0.9-2KCnLAEX6LA5YHxtEpLDUO
    lua-2.3.3-8SYrA1CAYT85bngYHR6FzJ text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua-repl/html/hslua-repl.haddock
haddock-html:         /usr/share/doc/haskell-hslua-repl/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-repl-0.1.2-141-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-repl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-repl
version:              0.1.2
visibility:           public
id:                   hslua-repl-0.1.2-JqaljPjGfM4G6LZEBISSdW
key:                  hslua-repl-0.1.2-JqaljPjGfM4G6LZEBISSdW
license:              MIT
copyright:            © 2023-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Isocline-based Lua REPL
description:          An embeddable Lua REPL built with Isocline and HsLua.
category:             Foreign
abi:                  7e79574b8fbb44acde76807b31cd0cdf
exposed:              True
exposed-modules:      HsLua.REPL
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-repl-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-repl-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-repl-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-repl
hs-libraries:         HShslua-repl-0.1.2-JqaljPjGfM4G6LZEBISSdW
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
    isocline-1.0.9-2KCnLAEX6LA5YHxtEpLDUO
    lua-2.3.3-DlJXYaKcRYH9BfYMQSRTd9 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua-repl/html/hslua-repl.haddock
haddock-html:         /usr/share/doc/haskell-hslua-repl/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
